@@ -1112,6 +1112,10 @@ def load_settings():
         "unsplash-width": 1920,
         "unsplash-height": 1080,
         "unsplash-keywords": ["nature", "water", "landscape"],
+        "wallhaven-ratio": "16x9,16x10",
+        "wallhaven-atleast": "1920x1080",
+        "wallhaven-api-key": "",
+        "wallhaven-tags": ["nature", "landscape"],
         "help-font-size": 12,
         "help-layer-shell": True,
         "help-keyboard": False,
